The `vcreview` cube provides a code review system on top of the
`vcsfile cube`_. It has been developped with the workflow we use at
Logilab_ in mind, historically based on `mercurial`_ and its `mq`_
extension, and now based on the `evolve`_ extension.


.. _`vcsfile cube`: http://www.cubicweb.org/project/cubicweb-vcsfile
.. _`mercurial`: http://mercurial.selenic.com
.. _`mq`: http://mercurial.selenic.com/wiki/MqExtension
.. _Logilab: http://www.logilab.fr
.. _`evolve`: http://mercurial.selenic.com/wiki/EvolveExtension
